'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = create;

var _ora = require('ora');

var _ora2 = _interopRequireDefault(_ora);

var _shelljs = require('shelljs');

var _isEmpty = require('lodash/isEmpty');

var _isEmpty2 = _interopRequireDefault(_isEmpty);

var _isString = require('lodash/isString');

var _isString2 = _interopRequireDefault(_isString);

var _commonErrors = require('common-errors');

var _logger = require('../logger');

var _logger2 = _interopRequireDefault(_logger);

var _utils = require('../utils');

var _setup = require('../setup');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function create(name) {
  if (!(0, _isString2.default)(name)) {
    throw new _commonErrors.TypeError('name is not a string');
  }

  if ((0, _isEmpty2.default)(name)) {
    throw new _commonErrors.ArgumentNullError('name');
  }

  var projectDir = (0, _utils.resolvePath)(name);

  // 1. Create project folder
  (0, _setup.createProjectSync)(projectDir);

  // 2. Initialize package.json
  (0, _setup.configPackageSync)();

  // 3. Copy templates to src folder
  (0, _setup.copyTemplates)(projectDir)
  // 4. Install dependencies
  .then(function () {
    return (0, _setup.installPackage)();
  }).then(function () {
    // 5. Setup version control
    (0, _setup.versionControlSync)();

    // Notify creation success
    (0, _ora2.default)('Project ' + name + ' is successfully created (' + projectDir + ')').succeed();
  }).catch(function (errors) {
    errors.forEach(function (error) {
      _logger2.default.error(error);
      (0, _shelljs.exit)(1);
    });
  });
}
//# sourceMappingURL=create.js.map