'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = generate;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _ora = require('ora');

var _ora2 = _interopRequireDefault(_ora);

var _isString = require('lodash/isString');

var _isString2 = _interopRequireDefault(_isString);

var _kebabCase = require('lodash/kebabCase');

var _kebabCase2 = _interopRequireDefault(_kebabCase);

var _changeCase = require('change-case');

var _changeCase2 = _interopRequireDefault(_changeCase);

var _path = require('path');

var _utils = require('../utils');

var _logger = require('../logger');

var _logger2 = _interopRequireDefault(_logger);

var _template = require('../template');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function generate(type, feature, name) {
  if (!(0, _isString2.default)(type)) {
    throw new TypeError('type is not a string');
  }

  if (!(0, _isString2.default)(feature)) {
    throw new TypeError('feature is not a string');
  }

  if (!(0, _isString2.default)(name)) {
    throw new TypeError('name is not a string');
  }

  var destination = (0, _utils.resolvePath)('src/' + (0, _kebabCase2.default)(feature));
  var targetPath = destination + '/' + _changeCase2.default.pascalCase(name) + '.js';

  (0, _mkdirp2.default)((0, _path.dirname)(targetPath), function (createDirError) {
    if (createDirError) {
      throw createDirError;
    }

    _fs2.default.writeFile(targetPath, (0, _template.generateComponent)(name), function (error) {
      var spinner = (0, _ora2.default)('Generated ' + type + ' in ' + targetPath).start();

      if (error) {
        _logger2.default.error(error);
        spinner.fail();
        throw error;
      }

      spinner.succeed();
    });
  });
}
//# sourceMappingURL=generate.js.map