import ora from 'ora';
import { exit } from 'shelljs';
import isEmpty from 'lodash/isEmpty';
import isString from 'lodash/isString';

import {
  ArgumentNullError, TypeError,
} from 'common-errors';

import logger from '../logger';

import { resolvePath } from '../utils';

import {
  createProjectSync,
  copyTemplates,
  configPackageSync,
  installPackage,
  versionControlSync,
} from '../setup';

export default function create(name) {
  if (!isString(name)) {
    throw new TypeError('name is not a string');
  }

  if (isEmpty(name)) {
    throw new ArgumentNullError('name');
  }

  const projectDir = resolvePath(name);

  // 1. Create project folder
  createProjectSync(projectDir);

  // 2. Initialize package.json
  configPackageSync();

  // 3. Copy templates to src folder
  copyTemplates(projectDir)
    // 4. Install dependencies
    .then(() => installPackage())
    .then(() => {
      // 5. Setup version control
      versionControlSync();

      // Notify creation success
      ora(`Project ${name} is successfully created (${projectDir})`).succeed();
    })
    .catch((errors) => {
      errors.forEach((error) => {
        logger.error(error);
        exit(1);
      });
    });
}
