// @flow

import fs from 'fs';
import mkdirp from 'mkdirp';
import ora from 'ora';
import isString from 'lodash/isString';
import kebabCase from 'lodash/kebabCase';
import changeCase from 'change-case';
import { dirname } from 'path';

import { resolvePath } from '../utils';
import logger from '../logger';
import {
  generateComponent,
} from '../template';

export default function generate(type: string, feature: string, name: string) {
  if (!isString(type)) {
    throw new TypeError('type is not a string');
  }

  if (!isString(feature)) {
    throw new TypeError('feature is not a string');
  }

  if (!isString(name)) {
    throw new TypeError('name is not a string');
  }

  const destination = resolvePath(`src/${kebabCase(feature)}`);
  const targetPath = `${destination}/${changeCase.pascalCase(name)}.js`;

  mkdirp(dirname(targetPath), (createDirError) => {
    if (createDirError) {
      throw createDirError;
    }

    fs.writeFile(targetPath, generateComponent(name), (error) => {
      const spinner = ora(`Generated ${type} in ${targetPath}`).start();

      if (error) {
        logger.error(error);
        spinner.fail();
        throw error;
      }

      spinner.succeed();
    });
  });
}
